@@ -1,23 +1,6 @@
-/*
-* Copyright (C) 2021 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Zhang Qipeng <zhangqipeng@uniontech.com>
-*
-* Maintainer: Zhang Qipeng <zhangqipeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef LOGINMODULEINTERFACE_H
 #define LOGINMODULEINTERFACE_H
@@ -83,6 +66,27 @@ enum AuthType {
     AT_All = -1                  // all
 };
 
+/**
+ * @brief The AuthStatus enum
+ * 认证状态
+ */
+enum AuthState {
+    AS_None = -1,   // none
+    AS_Success,     // 成功，此次认证的最终结果
+    AS_Failure,     // 失败，此次认证的最终结果
+    AS_Cancel,      // 取消，当认证没有给出最终结果时，调用 End 会出发 Cancel 信号
+    AS_Timeout,     // 超时
+    AS_Error,       // 错误
+    AS_Verify,      // 验证中
+    AS_Exception,   // 设备异常，当前认证会被 End
+    AS_Prompt,      // 设备提示
+    AS_Started,     // 认证已启动，调用 Start 之后，每种成功开启都会发送此信号
+    AS_Ended,       // 认证已结束，调用 End 之后，每种成功关闭的都会发送此信号，当某种认证类型被锁定时，也会触发此信号
+    AS_Locked,      // 认证已锁定，当认证类型锁定时，触发此信号。该信号不会给出锁定等待时间信息
+    AS_Recover,     // 设备恢复，需要调用 Start 重新开启认证，对应 AS_Exception
+    AS_Unlocked     // 认证解锁，对应 AS_Locked
+};
+
 /**
  * @brief 验证回调函数
  * @param const AuthCallbackData * 需要传回的验证数据
