@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "lockworker.h"
 
 #include "authcommon.h"
@@ -128,7 +132,8 @@ void LockWorker::initConnections()
             endAuthentication(m_account, AT_All);
             destoryAuthentication(m_account);
         } else {
-            createAuthentication(m_model->currentUser()->name());
+            if(m_login1SessionSelf->active())
+                createAuthentication(m_model->currentUser()->name());
         }
         emit m_model->prepareForSleep(isSleep);
     });
@@ -369,6 +374,8 @@ void LockWorker::doPowerAction(const SessionBaseModel::PowerAction action)
             delayTime = 500;
         }
         QTimer::singleShot(delayTime, this, [=] {
+            // 待机休眠前设置Locked为true,避免刚唤醒时locked状态不对
+            setLocked(true);
             m_sessionManagerInter->RequestSuspend();
         });
     }
@@ -386,6 +393,8 @@ void LockWorker::doPowerAction(const SessionBaseModel::PowerAction action)
             delayTime = 500;
         }
         QTimer::singleShot(delayTime, this, [=] {
+            // 待机休眠前设置Locked为true,避免刚唤醒时locked状态不对
+            setLocked(true);
             m_sessionManagerInter->RequestHibernate();
         });
     }
@@ -695,13 +704,6 @@ void LockWorker::onUnlockFinished(bool unlocked)
     //To Do: 最好的方案是修改同步后端认证信息的代码设计
     if (m_model->currentModeState() == SessionBaseModel::ModeStatus::UserMode)
         m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
-
-    //    if (!unlocked && m_authFramework->GetAuthType() == AuthFlag::Password) {
-    //        qWarning() << "Authorization password failed!";
-    //        emit m_model->authFailedTipsMessage(tr("Wrong Password"));
-    //        return;
-    //    }
-
     switch (m_model->powerAction()) {
     case SessionBaseModel::PowerAction::RequireRestart:
         if (unlocked) {
