@@ -1,23 +1,6 @@
-/*
-* Copyright (C) 2021 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Yin Jie <yinjie@uniontech.com>
-*
-* Maintainer: Yin Jie <yinjie@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
@@ -30,8 +13,10 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+#ifdef PREFER_USING_GM
 #include <openssl/sm2.h>
 #include <openssl/sm4.h>
+#endif
 #ifdef __cplusplus
 }
 #endif
@@ -63,7 +48,9 @@ private:
     ~EncryptHelper();
 
     QByteArray RSAEncryptSymmetricalKey();
+#ifdef PREFER_USING_GM
     QByteArray SM2EncryptSymmetricalKey();
+#endif
 
 private:
     BIO *m_BIO;
