@@ -1,23 +1,6 @@
-/*
-* Copyright (C) 2021 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Zhang Qipeng <zhangqipeng@uniontech.com>
-*
-* Maintainer: Zhang Qipeng <zhangqipeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "auth_single.h"
 
@@ -273,8 +256,9 @@ void AuthSingle::setLimitsInfo(const LimitsInfo &info)
     AuthModule::setLimitsInfo(info);
     setPasswordHintBtnVisible(info.numFailures > 0 && !m_passwordHint.isEmpty());
     if (m_limitsInfo->locked) {
-        if (lockStateChanged && this->isVisible() && QFile::exists(ResetPassword_Exe_Path) &&
-            m_currentUid <= 9999 && !IsCommunitySystem ) {
+        bool isShow = lockStateChanged && this->isVisible() && QFile::exists(DEEPIN_DEEPINID_DAEMON_PATH) &&
+                QFile::exists(ResetPassword_Exe_Path) && m_currentUid <= 9999 && !IsCommunitySystem;
+        if (isShow) {
             qDebug() << "begin reset passoword";
             setResetPasswordMessageVisible(true);
             updateResetPasswordUI();
@@ -509,7 +493,7 @@ bool AuthSingle::isUserAccountBinded()
         return false;
     }
     QString uosid;
-    if (retUOSID.error().message().isEmpty()) {
+    if (retUOSID.isValid()) {
         uosid = retUOSID.value();
     } else {
         qWarning() << retUOSID.error().message();
@@ -531,7 +515,7 @@ bool AuthSingle::isUserAccountBinded()
         return false;
     }
     QString ubid;
-    if (retLocalBindCheck.error().message().isEmpty()) {
+    if (retLocalBindCheck.isValid()) {
         ubid = retLocalBindCheck.value();
         if (m_bindCheckTimer) {
             m_bindCheckTimer->stop();
