@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "sessionbasemodel.h"
 
 #include <DSysInfo>
@@ -25,6 +29,7 @@ SessionBaseModel::SessionBaseModel(QObject *parent)
     , m_allowShowCustomUser(false)
     , m_SEOpen(false)
     , m_isUseWayland(QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive))
+    , m_pressedPowerBtnFromLock(false)
     , m_appType(AuthCommon::None)
     , m_currentUser(nullptr)
     , m_lastLogoutUser(nullptr)
@@ -236,6 +241,16 @@ void SessionBaseModel::setAllowShowCustomUser(const bool allowShowCustomUser)
     m_allowShowCustomUser = allowShowCustomUser;
 }
 
+void SessionBaseModel::powerBtnPressedFromLock()
+{
+    m_pressedPowerBtnFromLock = true;
+}
+
+void SessionBaseModel::resetPowerBtnPressedFromLock()
+{
+    m_pressedPowerBtnFromLock = false;
+}
+
 /**
  * @brief 认证类型
  *
@@ -653,4 +668,4 @@ void SessionBaseModel::updateAuthState(const int type, const int state, const QS
         emit authStateChanged(AT_PAM, state, message);
         break;
     }
-}
+}
\ No newline at end of file
