@@ -1,27 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "shutdownwidget.h"
 #include "multiuserswarningview.h"
@@ -560,10 +539,16 @@ bool ShutdownWidget::event(QEvent *e)
         m_frameDataBind->updateValue("ShutdownWidget", m_index);
         m_btnList.at(m_index)->updateState(RoundItemButton::Checked);
     } else if (e->type() == QEvent::FocusOut) {
-        if (m_index < 0 || m_index >= m_btnList.size()) {
-            m_index = 0;
+        if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode) {
+            // 丢失焦点后，获取焦点。双屏拔掉一个显示器会导致焦点丢失
+            if (this->isVisible())
+                this->activateWindow();
+        } else {
+            if (m_index < 0 || m_index >= m_btnList.size()) {
+                m_index = 0;
+            }
+            m_btnList.at(m_index)->updateState(RoundItemButton::Normal);
         }
-        m_btnList.at(m_index)->updateState(RoundItemButton::Normal);
     }
 
     return QFrame::event(e);
